/***************************************************************************//**
*   @file   AD7303.c
*   @brief  AD7303 Driver.
*   @author ATofan (alexandru.tofan@analog.com)
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: $WCREV$
*******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <xparameters.h>
#include <xil_io.h>
#include "AD7303.h"

/******************************************************************************
* @brief Writes data to the AD7303 DAC.
*
* @param data0 - Data to be written to the DAC
*
* @return None.
******************************************************************************/
void AD7303WriteData0(int data0)
{
	Xil_Out32(Data0Reg, data0);
}

/******************************************************************************
* @brief Writes data to the AD7303 DAC.
*
* @param data1 - Data to be written to the DAC
*
* @return None.
******************************************************************************/
void AD7303WriteData1(int data1)
{
	Xil_Out32(Data1Reg, data1);
}

/******************************************************************************
* @brief Writes data to the control register.
*
* @param ctrl0 - Data to be written to the control register
*
* @return None.
******************************************************************************/
void AD7303WriteCtrl0(int ctrl0)
{
	Xil_Out32(Ctrl0Reg, ctrl0);
}

/******************************************************************************
* @brief Writes data to the control register.
*
* @param ctrl1 - Data to be written to the control register
*
* @return None.
******************************************************************************/
void AD7303WriteCtrl1(int ctrl1)
{
	Xil_Out32(Ctrl1Reg, ctrl1);
}

/******************************************************************************
* @brief Starts SPI Communication with the Slave device.
*
* @return None.
******************************************************************************/
void AD7303Start(void)
{
	Xil_Out32(StartReg, 0x01);
}

/******************************************************************************
* @brief Stops SPI Communication with the Slave device.
*
* @return None.
******************************************************************************/
void AD7303Stop(void)
{
	Xil_Out32(StartReg, 0x00);
}

/******************************************************************************
* @brief Initiates a conversion.
*
* @return None.
******************************************************************************/
void AD7303Convert(void)
{
	AD7303Start();
	AD7303Stop();
}

/******************************************************************************
* @brief Reads data from the first AD7303 on the Pmod.
*
* @return rdata - Data read from the Pmod.
******************************************************************************/
int AD7303ReadData0(void)
{
	int rdata;
	rdata = Xil_In32(Data0Reg);
	return(rdata);
}

/******************************************************************************
* @brief Reads data from the second AD7303 on the Pmod.
*
* @return rdata - Data read from the Pmod.
******************************************************************************/
int AD7303ReadData1(void)
{
	int rdata;
	rdata = Xil_In32(Data1Reg);
	return(rdata);
}

/******************************************************************************
* @brief Reads data from the first AD7303 on the Pmod.
*
* @return rdata - Data read from the Pmod.
******************************************************************************/
int AD7303ReadCtrl0(void)
{
	int rdata;
	rdata = Xil_In32(Ctrl0Reg);
	return(rdata);
}

/******************************************************************************
* @brief Reads data from the second AD7303 on the Pmod.
*
* @return rdata - Data read from the Pmod.
******************************************************************************/
int AD7303ReadCtrl1(void)
{
	int rdata;
	rdata = Xil_In32(Ctrl1Reg);
	return(rdata);
}

/******************************************************************************
* @brief Reads data from the Start Register in the Custom Communication Core.
*
* @return rdata - Data read from the Core.
******************************************************************************/
int AD7303ReadStart(void)
{
	int rdata;
	rdata = Xil_In32(StartReg);
	return(rdata);
}
