/***************************************************************************//**
*   @file   main.c
*   @brief  Main File for AD7303 Driver.
*   @author ATofan (alexandru.tofan@analog.com)
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: $WCREV$
*******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <stdio.h>
#include "xparameters.h"
#include "xil_cache.h"
#include "AD7303.h"

/******************************************************************************
* @brief Main function.
*
* @return Always returns 0.
******************************************************************************/
int main()
{
   int i;
   int j = 0;
   Xil_ICacheEnable();
   Xil_DCacheEnable();
   AD7303WriteData0(0x0000000000);
   AD7303WriteData1(0x0000000000);
   AD7303WriteCtrl0(0x0000000003);
   AD7303WriteCtrl1(0x0000000003);
   while(1)
   {
	   // Available modes:
	   /*
	    	* Square Wave   - squaretable[i]
	    	* Triangle Wave - triangletable[i]
	    	* Sawtooth Wave - sawtable[i]
	    	* Sine Wave     - sinetable[i]
	      Replace with desired mode for either Channel0
	      or Channel1 in the AD7303WriteData commands below
	    */
	   AD7303WriteData0(squaretable[i]);
	   AD7303WriteData1(triangletable[i]);
	   AD7303Convert();
	   i+=1;
	   if(i>255)
	   {
		   i = 0;
	   }
   }
   Xil_DCacheDisable();
   Xil_ICacheDisable();

   return 0;
}

